Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(4374)

Unified Diff: chrome/browser/chromeos/gdata/gdata_download_observer.h

Issue 10877005: Rename GDataCache* to DriveCache* (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: rebase. Created 8 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/chromeos/gdata/gdata_download_observer.h
diff --git a/chrome/browser/chromeos/gdata/gdata_download_observer.h b/chrome/browser/chromeos/gdata/gdata_download_observer.h
index eb1476513a1fb6898226405fd116da0f585df294..80a990ceae7d44d368748eb675f7759e87dceb37 100644
--- a/chrome/browser/chromeos/gdata/gdata_download_observer.h
+++ b/chrome/browser/chromeos/gdata/gdata_download_observer.h
@@ -139,7 +139,7 @@ class GDataDownloadObserver : public content::DownloadManager::Observer,
// Callback invoked by GDataUploader when the upload associated with
// |download_id| has completed. |error| indicated whether the
// call was successful. This function takes ownership of DocumentEntry from
// |upload_file_info| for use by MoveFileToGDataCache(). It also invokes the
// MaybeCompleteDownload() method on the DownloadItem to allow it to complete.
void OnUploadComplete(int32 download_id,
GDataFileError error,
@@ -147,7 +147,7 @@ class GDataDownloadObserver : public content::DownloadManager::Observer,
// Moves the downloaded file to gdata cache.
// Must be called after GDataDownloadObserver receives COMPLETE notification.
- void MoveFileToGDataCache(content::DownloadItem* download);
+ void MoveFileToDriveCache(content::DownloadItem* download);
// Private data.
// The uploader owned by GDataSystemService. Used to trigger file uploads.
« no previous file with comments | « chrome/browser/chromeos/gdata/gdata_cache_unittest.cc ('k') | chrome/browser/chromeos/gdata/gdata_download_observer.cc » ('j') | no next file with comments »
@@ -139,7 +139,7 @@ class GDataDownloadObserver : public content::DownloadManager::Observer,
// |download_id| has completed. |error| indicated whether the
// call was successful. This function takes ownership of DocumentEntry from
- // |upload_file_info| for use by MoveFileToGDataCache(). It also invokes the
+ // |upload_file_info| for use by MoveFileToDriveCache(). It also invokes the
// MaybeCompleteDownload() method on the DownloadItem to allow it to complete.
void OnUploadComplete(int32 download_id,

Powered by Google App Engine
This is Rietveld 408576698